==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/pink/objects/actors/inventory_actor.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef PINK_INVENTORY_ACTOR_H
#define PINK_INVENTORY_ACTOR_H

#include "common/debug.h"

#include "pink/objects/actions/action.h"
#include "pink/objects/actors/actor.h"

namespace Pink {

class InventoryActor : public Actor {
public:
	void toConsole() override {
		debugC(6, kPinkDebugLoadingObjects, "InventoryActor: _name = %s", _name.c_str());
		for (uint i = 0; i < _actions.size(); ++i) {
			_actions[i]->toConsole();
		}
	}

	void pause(bool paused) override {}

	void init(bool paused) override {
		Actor::init(0);
	}
};

} // End of namespace Pink

#endif

==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/engines/pink/objects/actors/inventory_actor.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef PINK_INVENTORY_ACTOR_H
#define PINK_INVENTORY_ACTOR_H

#include "common/debug.h"

#include "pink/objects/actions/action.h"
#include "pink/objects/actors/actor.h"

namespace Pink {

class InventoryActor : public Actor {
public:
	void toConsole() const override {
		debugC(6, kPinkDebugLoadingObjects, "InventoryActor: _name = %s", _name.c_str());
		for (uint i = 0; i < _actions.size(); ++i) {
			_actions[i]->toConsole();
		}
	}

	void pause(bool paused) override {}

	void init(bool paused) override {
		Actor::init(0);
	}
};

} // End of namespace Pink

#endif
